PFont font;
float freq; 

// COLORS: 
//#262E45,#37344F,#4A3958,#5D3D5E,#714163
//#854466,#994867,#AB4D65,#BD5362,#CC5B5D

// Layout variables 
float constantHorizontalMargin = 160;
float constantVerticalMargin = 40;

// width and height for each cell
float cellWidth, cellHeight;

// 2D matrix table related variables
Table table;

int numRows, numColumns;
float[][] dataMatrix;
float maxValue, minValue;

String[] titles;
int[] checkouts;

PImage colorBar;
String[] colorPath = {"colorblend1.jpg"};
boolean colorScheme = false;

void setup(){
  size(1456, 820); // setup the size of the window
  // In Processing 3, the size() function must be the first line of code inside setup()
  // and needs to use numbers instead of variables. 

  // Make the screen resizable.                     
  surface.setResizable(true);
  
  //Put data into Processing table from csv
  table = loadTable("fem_monthly.csv", "header");
  
  // Get row and column information
  numRows = table.getRowCount(); 
  numColumns = table.getColumnCount();
  println("Rows: " + numRows + " Columns: " + numColumns);
  
  // Create a 2D array to receive data from the table 
  dataMatrix = new float[numRows][numColumns-2]; // doesn't need the first two columns 
  titles = new String[numRows];
  checkouts = new int[numRows];
  
  for(int i=0; i<numRows; i++){
    for(int j=0; j<numColumns-2; j++){
      dataMatrix[i][j] = log(table.getFloat(i,j+2)+1);
     
      //Find the max value of the whole data
      if(dataMatrix[i][j] > maxValue){
        maxValue = dataMatrix[i][j];
      }
    }
    
    // put title and checkout data from the table to the array
    titles[i] = table.getString(i, 0);
    checkouts[i] = table.getInt(i, 1);
  }
  
  // Find the min value of the whole data
  minValue = maxValue;
  for(int i=0; i<dataMatrix.length; i++){
    for(int j=0; j<dataMatrix[0].length; j++){
      if(dataMatrix[i][j] < minValue){
        minValue = dataMatrix[i][j];
      }
    }
  }
  
  println("Max Value is " + maxValue);
  println("Min Value is " + minValue);
  
  //modifying the cell size according to window size
  cellWidth = (width - constantHorizontalMargin*2)/(numColumns-2);
  cellHeight = (height - constantVerticalMargin*2)/numRows;
}

void draw(){
  background(225);
  translate(60, 0);
    
  //Draw 2D Matrix
  for(int i=0; i<dataMatrix.length; i++){
    for(int j=0; j<dataMatrix[0].length; j++){
      stroke(50);
      strokeWeight(1);
      colorMode(HSB, 255, 255, 255);
      
      freq = map(dataMatrix[i][j], minValue, maxValue, 65, 255);
    
    if(!colorScheme){
        float greyScale = map(dataMatrix[i][j], minValue, maxValue, 255, 0);
        fill(greyScale);
      }
      else{
        color c = colorBar.get((int)map(dataMatrix[i][j], minValue, maxValue, 2, colorBar.width-2), colorBar.height/2);
        fill(c);
      }
      rect(constantHorizontalMargin + cellWidth*j, constantVerticalMargin 
           + cellHeight*i, cellWidth, cellHeight);
    }
  }
  
  //Draw horizontal labels
  for(int i=0; i<11; i++){
    int year = 2007;
    textSize(10);
    textAlign(CENTER, TOP);
    fill(0);
    text(year+i, constantHorizontalMargin + cellWidth*(6+12*i), 
         constantVerticalMargin +cellHeight*numRows + 5);
         
    //draw the seperation lines
    if(i != 0){
      stroke(#AB4D65);
      line(constantHorizontalMargin + cellWidth*(12*i), constantVerticalMargin +cellHeight*numRows + 3,  
           constantHorizontalMargin + cellWidth*(12*i), constantVerticalMargin +cellHeight*numRows + 20);
    }
  }
   
  //Draw vertical labels
  for(int i=0; i<numRows; i++){
    textAlign(RIGHT, CENTER);
    fill(0);
    textSize(10);
    text(titles[i], constantHorizontalMargin-3, constantVerticalMargin +cellHeight*(0.5+i));
    
     //show total number on the right side
    textAlign(LEFT, CENTER);
    text(checkouts[i], width-constantHorizontalMargin+3,constantVerticalMargin +cellHeight*(0.5+i));
  }
  
  //Draw Title
  textAlign(CENTER, CENTER);
  textSize(16);
  text("Top Feminism/Feminist Checked-Out From SPL", width/2, constantVerticalMargin/2);
}

void keyPressed(){
    if(key == '0'){
      colorScheme = false;
    }
    else if(key == '1'){
      colorScheme = true;
      colorBar = loadImage(colorPath[0]);
    }
}